<?php
/**
 * Dolpa functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Dolpa
 */


if ( ! function_exists( 'dolpa_after_theme_support' ) ) :

	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */

	function dolpa_after_theme_support() {

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		// Custom background color.
		add_theme_support(
			'custom-background',
			array(
				'default-color' => 'ffffff',
			)
		);

		// This variable is intended to be overruled from themes.
		// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
		// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
		$GLOBALS['content_width'] = apply_filters( 'dolpa_content_width', 1140 );
		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		add_theme_support('custom-logo', array(
            'height' => 250,
            'width' => 250,
            'flex-width' => true,
            'flex-height' => true,
        ));

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support(
			'html5',
			array(
				'search-form',
				'comment-form',
				'comment-list',
				'gallery',
				'caption',
				'script',
				'style',
			)
		);

		/*
		 * Posts Formate.
		 *
		 * https://wordpress.org/support/article/post-formats/
		 */
		add_theme_support( 'post-formats', array(
		    'video',
		    'audio',
		    'gallery',
		    'quote',
		    'image'
		) );

		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on Dolpa, use a find and replace
		 * to change 'dolpa' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'dolpa', get_template_directory() . '/languages' );

		// Add support for full and wide align images.
		add_theme_support( 'align-wide' );

	}

endif;

add_action( 'after_setup_theme', 'dolpa_after_theme_support' );

/**
 * Register and Enqueue Styles.
 */
function dolpa_register_styles() {

	 $fonts_url = Dolpa_Fonts::dolpa_get_fonts_url();
    if (!empty($fonts_url)) {
        wp_enqueue_style('dolpa-google-fonts', $fonts_url, array(), null);
    }

	$theme_version = wp_get_theme()->get( 'Version' );

    wp_enqueue_style( 'dolpa-font-ionicons', get_template_directory_uri() . '/assets/lib/ionicons/css/ionicons.min.css');
    wp_enqueue_style( 'slick', get_template_directory_uri() . '/assets/lib/slick/css/slick.min.css');
    wp_enqueue_style( 'aos', get_template_directory_uri() . '/assets/lib/aos/css/aos.css');
    wp_enqueue_style( 'dolpa-style', get_stylesheet_uri(), array(), $theme_version );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}	

	wp_enqueue_script( 'imagesloaded' );
    wp_enqueue_script( 'masonry' );
	wp_enqueue_script( 'slick', get_template_directory_uri() . '/assets/lib/slick/js/slick.min.js', array('jquery'), '', 1);
    wp_enqueue_script( 'theiaStickySidebar', get_template_directory_uri() . '/assets/lib/theiaStickySidebar/theia-sticky-sidebar.js', array('jquery'), '', 1);
    wp_enqueue_script( 'aos', get_template_directory_uri() . '/assets/lib/aos/js/aos.js', array('jquery'), '', true);
	wp_enqueue_script( 'dolpa-pagination', get_template_directory_uri() . '/assets/lib/custom/js/pagination.js', array('jquery'), '', 1 );
	wp_enqueue_script( 'dolpa-custom', get_template_directory_uri() . '/assets/lib/custom/js/custom.js', array('jquery'), '', 1);

	$ajax_nonce = wp_create_nonce('dolpa_ajax_nonce');
	
	if( is_page_template('templates/template-aside-default.php') || 
		is_page_template('templates/template-aside-lateral.php') || 
		is_page_template('templates/template-aside-metro.php') ){

			$banner_post_id = dolpa_aside_banner_post_id();
			
	        
	        $twp_paged = ( get_query_var( 'paged' ) > 1 ) ? get_query_var( 'paged' ) : 1;
	        $aside_post_query = new WP_Query( array( 'post_type'=>'post', 'paged'=>$twp_paged,'post__not_in' => array($banner_post_id) ) );
	        $max = $aside_post_query->max_num_pages;

    }else{

	    // Global Query
	    if( is_front_page() ){

	    	$posts_per_page = absint( get_option('posts_per_page') );
	        $twp_paged = ( get_query_var( 'page' ) ) ? absint( get_query_var( 'page' ) ) : 1;
	        $posts_args = array(
	            'posts_per_page'        => $posts_per_page,
	            'paged'                 => $twp_paged,
	        );
	        $posts_qry = new WP_Query( $posts_args );
	        $max = $posts_qry->max_num_pages;
	        wp_reset_postdata();
	    }else{
	        global $wp_query;
	        $max = $wp_query->max_num_pages;
	        $twp_paged = ( get_query_var( 'paged' ) > 1 ) ? get_query_var( 'paged' ) : 1;
	    }

	}

    $dolpa_default = dolpa_get_default_theme_options();
    $dolpa_pagination_layout = get_theme_mod( 'dolpa_pagination_layout',$dolpa_default['dolpa_pagination_layout'] );

    // Pagination Data
    wp_localize_script( 
	    'dolpa-pagination', 
	    'dolpa_pagination',
	    array(
	        'paged'  => absint( $twp_paged ),
	        'maxpage'   => absint( $max ),
	        'nextLink'   => next_posts( $max, false ),
	        'ajax_url'   => esc_url( admin_url( 'admin-ajax.php' ) ),
	        'loadmore'   => esc_html__( 'Load More Posts', 'dolpa' ),
	        'nomore'     => esc_html__( 'No More Posts', 'dolpa' ),
	        'loading'    => esc_html__( 'Loading...', 'dolpa' ),
	        'pagination_layout'   => esc_html( $dolpa_pagination_layout ),
	        'ajax_nonce' => $ajax_nonce,
	     )
	);

    global $post;
    $single_post = 0;
    $dolpa_ed_post_reaction = '';
    if( isset( $post->ID ) && isset( $post->post_type ) && $post->post_type == 'post' ){

    	$dolpa_ed_post_reaction = esc_html( get_post_meta( $post->ID, 'dolpa_ed_post_reaction', true ) );
    	$single_post = 1;

    }
	wp_localize_script(
	    'dolpa-custom', 
	    'dolpa_custom',
	    array(
	    	'single_post'	=> absint( $single_post ),
	        'dolpa_ed_post_reaction'  		=> esc_html( $dolpa_ed_post_reaction ),
	     )
	);

}

add_action( 'wp_enqueue_scripts', 'dolpa_register_styles' );

/**
 * Admin enqueue script
 */
function dolpa_admin_scripts($hook){

    wp_enqueue_style('dolpa-admin', get_template_directory_uri() . '/assets/lib/custom/css/admin.css');
    wp_enqueue_script('dolpa-admin', get_template_directory_uri() . '/assets/lib/custom/js/admin.js', array('jquery'), '', 1);
    
    $ajax_nonce = wp_create_nonce('dolpa_ajax_nonce');
            
    wp_localize_script( 
        'dolpa-admin', 
        'dolpa_admin',
        array(
            'ajax_url'   => esc_url( admin_url( 'admin-ajax.php' ) ),
            'ajax_nonce' => $ajax_nonce,
            'active' => esc_html__('Active','dolpa'),
            'deactivate' => esc_html__('Deactivate','dolpa'),
         )
    );

    $current_screen = get_current_screen();
    if( $current_screen->id === "widgets" ) {

        // Enqueue Script Only On Widget Page.
        wp_enqueue_media();
    	wp_enqueue_script('dolpa-widget', get_template_directory_uri() . '/assets/lib/custom/js/widget.js', array('jquery'), '', 1);
	}

}

add_action('admin_enqueue_scripts', 'dolpa_admin_scripts');

if( !function_exists( 'dolpa_js_no_js_class' ) ) :

	// js no-js class toggle
	function dolpa_js_no_js_class() { ?>

		<script>document.documentElement.className = document.documentElement.className.replace( 'no-js', 'js' );</script>
	
	<?php
	}
	
endif;

add_action( 'wp_head', 'dolpa_js_no_js_class' );

/**
 * Register navigation menus uses wp_nav_menu in five places.
 */
function dolpa_menus() {

	$locations = array(
		'dolpa-primary-menu'  => __( 'Primary Menu', 'dolpa' ),
		'dolpa-footer-menu'  => __( 'Footer Menu', 'dolpa' ),
		'dolpa-social-menu'  => __( 'Social Menu', 'dolpa' ),
	);

	register_nav_menus( $locations );
}

add_action( 'init', 'dolpa_menus' );

/**
 * Add Description to Menu Items
 */
add_filter( 'walker_nav_menu_start_el', 'dolpa_add_description', 10, 2 );
function dolpa_add_description( $item_output, $item ) {
    $description = $item->post_content;
    if (('' !== $description) && (' ' !== $description) ) {
        return preg_replace( '/(<a.*)</', '$1' . '<span class="menu-description">' . esc_html( $description ) . '</span><', $item_output) ;
    }
    else {
        return $item_output;
    };
}

/**
 * Add Home Icon to Menu Items
 */

add_filter('wp_nav_menu_items', 'dolpa_add_admin_link', 1, 2);
function dolpa_add_admin_link($items, $args){
    if( $args->theme_location == 'dolpa-primary-menu' ){
        $item = '<li class="brand-home"><a title="'.esc_html__('Home','dolpa').'" href="'. esc_url( home_url() ) .'">' . "<span class='icon ion-ios-home'></span>" . '</a></li>';
        $items = $item . $items;
    }
    return $items;
}

/**
 * SVG Icons
 */
require get_template_directory() . '/classes/class-svg-icons.php';

/**
 * Customizer
 */
require get_template_directory() . '/inc/customizer/customizer.php';

/**
 * Related Posts
 */
require get_template_directory() . '/inc/single-related-posts.php';

/**
 * Custom Functions
 */
require get_template_directory() . '/inc/custom-functions.php';

/**
 * Template Functions
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Body Classes
 */
require get_template_directory() . '/classes/body-classes.php';

/**
 * Fonts
 */
require get_template_directory() . '/classes/classes-fonts.php';


/**
 * Widgets
 */
/**
 * Widgets
 */
require get_template_directory() . '/inc/widgets/widget-base.php';
require get_template_directory() . '/inc/widgets/widgets.php';
require get_template_directory() . '/inc/widgets/author.php';
require get_template_directory() . '/inc/widgets/category.php';
require get_template_directory() . '/inc/widgets/recent-post.php';
require get_template_directory() . '/inc/widgets/social-link.php';
require get_template_directory() . '/inc/widgets/tab-posts.php';

/**
 * Metabox
 */
require get_template_directory() . '/inc/metabox.php';

/**
 * Pagination
 */
require get_template_directory() . '/inc/pagination.php';

/**
 * Breadcrumbs
 */
require get_template_directory() . '/assets/lib/breadcrumbs/breadcrumbs.php';

/**
 * Dynamic Color.
 */
require get_template_directory() . '/assets/lib/custom/css/style.php';

/**
 * Recommended Plugins
 */
require get_template_directory() . '/assets/lib/tgmpa/recommended-plugins.php';

require get_template_directory() . '/classes/about-classes.php';
require get_template_directory() . '/classes/admin-notice.php';
require get_template_directory() . '/classes/plugins-classes.php';
require get_template_directory() . '/woocommerce/woocommerce-function.php';